@@ -2,6 +2,7 @@ import inspect
 import multiprocessing as mp
 import re
 import sys
+import traceback
 import typing as t
 from contextlib import contextmanager
 from functools import partial
@@ -15,7 +16,7 @@ import docstring_parser as dp
 import pandas as pd
 from pyqtgraph.Qt import QtWidgets, QtCore
 from pyqtgraph.parametertree import Parameter, ParameterTree
-from ruamel.yaml import YAML
+from ruamel.yaml import YAML, YAMLError
 from tqdm import tqdm
 
 from .typeoverloads import FilePath
@@ -340,7 +341,8 @@ def flexibleParamTree(topParam:Parameter, showTop=True):
     for ch in p:
       hookupSignals(ch)
     p.sigChildAdded.connect(lambda _p, _ch: hookupSignals(_ch))
-    setParamTooltips(tree)
+
+  setParamTooltips(tree)
   hookupSignals(topParam)
   return tree
 
@@ -443,7 +445,11 @@ def docParser(docstring: str):
   out = {}
   for param in parsed.params:
     stream = StringIO(param.description)
-    paramDoc = yaml.load(stream)
+    try:
+      paramDoc = yaml.load(stream)
+    except YAMLError:
+      # Some problem parsing, treat as string
+      paramDoc = param.description
     if isinstance(paramDoc, str):
       paramDoc = {'helpText': paramDoc}
     if paramDoc is None:
@@ -451,10 +457,11 @@ def docParser(docstring: str):
     out[param.arg_name] = PrjParam(name=param.arg_name, **paramDoc)
     if 'pType' not in paramDoc:
       out[param.arg_name].pType = None
+  # Wrap and extract for proper formatting
+  descr = PrjParam('', helpText=descr).helpText
   out['top-descr'] = descr
   return out
 
-
 def paramWindow(param: Parameter):
   tree = flexibleParamTree(param)
   tree.setHeaderHidden(True)
