@@ -3,7 +3,7 @@ from warnings import warn
 
 from pyqtgraph.Qt import QtWidgets, QtCore, QtGui
 
-from ..fns import clsNameOrGroup, params_flattened, getParamChild, helpTextToRichText
+from ..fns import clsNameOrGroup, params_flattened, getParamChild, warnLater
 from .parameditor import ParamEditor, PrjParam
 
 
@@ -80,48 +80,23 @@ class ShortcutsEditor(ParamEditor):
     shcChanged(None, btnOpts.value)
     return param
 
-  def createRegisteredButton(self, btnOpts: PrjParam,
-                             baseBtn: QtWidgets.QAbstractButton=None,
-                             asToolBtn=False,
-                             returnParam=False,
-                             **kwargs):
-    if btnOpts.value is not None:
-      self._checkUniqueShortcut(btnOpts)
-    if asToolBtn:
-      btnType = QtWidgets.QToolButton
-    else:
-      btnType = QtWidgets.QPushButton
-    tooltipText = btnOpts.helpText
-    if baseBtn is not None:
-      newBtn = baseBtn
-    elif 'icon' in btnOpts.opts:
-      newBtn = btnType(self)
-      newBtn.setIcon(QtGui.QIcon(btnOpts.opts['icon']))
-      tooltipText = helpTextToRichText(btnOpts.helpText, btnOpts.name)
-    else:
-      newBtn = btnType(self)
-      newBtn.setText(btnOpts.name)
+  def registerButton(self, btnOpts: PrjParam,
+                     baseBtn: QtWidgets.QAbstractButton,
+                     **kwargs):
     if btnOpts.value is None:
       # Either the shortcut wasn't given a value or wasn't requested, or already exists
-      newBtn.setToolTip(tooltipText)
-      if returnParam:
-        return newBtn, None
-      return newBtn
-    btnOpts.opts['tip'] = tooltipText
-
+      return None
+    self._checkUniqueShortcut(btnOpts)
     param = self._createSeq(btnOpts, **kwargs)
 
     def shcChanged(_param, newSeq: str):
       newTooltipText = f'Shortcut: {newSeq}'
-      tip = param.opts.get('tip', '')
-      tip = helpTextToRichText(tip, newTooltipText)
-      newBtn.setToolTip(tip)
-      newBtn.setShortcut(newSeq)
+      tip = btnOpts.addHelpText(newTooltipText, replace=False)
+      baseBtn.setToolTip(tip)
+      baseBtn.setShortcut(newSeq)
     param.sigValueChanged.connect(shcChanged)
     shcChanged(None, btnOpts.value)
-    if returnParam:
-      return newBtn, param
-    return newBtn
+    return param
 
   def maybeAmbigWarning(self, shortcut: str):
     conflicts = [p.name() for p in params_flattened(self.params) if p.value() == shortcut]
@@ -138,7 +113,7 @@ class ShortcutsEditor(ParamEditor):
 
     formatted = f'<{shortcutParam["name"]}: {shortcutParam["value"]}>'
     if len(matches) == 0:
-      warn(f'Shortcut param {formatted} does not exist. No delete performed.')
+      warnLater(f'Shortcut param {formatted} does not exist. No delete performed.')
       return
     for match in matches:
       # Set shortcut key to nothing to prevent its activation
