@@ -28,13 +28,15 @@ from .constants import PrjEnums
 from .params.prjparam import PrjParam
 
 # Taken directly from https://stackoverflow.com/a/20610786/9463643
+# Many things can cause this statement to fail
+# noinspection PyBroadException
 try:
   from pyqtgraph.Qt import QtWidgets
   from qtconsole.rich_jupyter_widget import RichJupyterWidget
   from qtconsole.inprocess import QtInProcessKernelManager
   from IPython.lib import guisupport
 
-except (ImportError, NotImplementedError):
+except Exception:
   from pyqtgraph.console import ConsoleWidget
 else:
 
@@ -97,6 +99,7 @@ class ScrollableErrorDialog(QtWidgets.QDialog):
     scrollArea.setWidgetResizable(True)
     scrollAreaWidgetContents = QtWidgets.QWidget()
 
+
     scrollLayout = QtWidgets.QVBoxLayout(scrollAreaWidgetContents)
 
     # Set to message with trace first so sizing is correct
